// CkCert.h: interface for the CkCert class.
//
//////////////////////////////////////////////////////////////////////
#ifndef _CKCERT_H
#define _CKCERT_H

#pragma once

class CkString;

#include "CkObject.h"

// CLASS: CkCert
class CkCert : public CkObject 
{
    private:
	void *m_impl;
	bool m_utf8;	// If true, all input "const char *" parameters are utf-8, otherwise they are ANSI strings.

	// Don't allow assignment or copying these objects.
	CkCert(const CkCert &) { } 
	CkCert &operator=(const CkCert &) { return *this; }

    public:
	void *getImpl(void) { return m_impl; } 

	CkCert(void *impl) : m_impl(impl) { }

	CkCert();
	virtual ~CkCert();

	// BEGIN PUBLIC INTERFACE
	bool get_Utf8(void) const;
	void put_Utf8(bool b);

	bool LoadFromFile(const char *filename);
	bool LoadFromBase64(const char *encodedCert);
	bool LoadFromBinary(const unsigned char *buf, unsigned long bufLen);
	bool SetFromEncoded(const char *encodedCert);
	bool GetEncoded(CkString &str);
	bool get_IsRoot(void);
	void get_IssuerE(CkString &str);
	void get_IssuerC(CkString &str);
	void get_IssuerS(CkString &str);
	void get_IssuerL(CkString &str);
	void get_IssuerO(CkString &str);
	void get_IssuerOU(CkString &str);
	void get_IssuerCN(CkString &str);
	void get_IssuerDN(CkString &str);
	void get_SubjectE(CkString &str);
	void get_SubjectC(CkString &str);
	void get_SubjectS(CkString &str);
	void get_SubjectL(CkString &str);
	void get_SubjectO(CkString &str);
	void get_SubjectOU(CkString &str);
	void get_SubjectCN(CkString &str);
	void get_SubjectDN(CkString &str);

	bool get_SignatureVerified(void);
	bool get_TrustedRoot(void);
	bool get_Revoked(void);
	bool get_Expired(void);

	bool HasPrivateKey(void);

	bool SaveToFile(const char *filename);

	// Subject Alternative Name (RFC822) -- Not present in all certificates.
	void get_Rfc822Name(CkString &str);
	
	void get_ValidTo(SYSTEMTIME &sysTime);
	void get_ValidFrom(SYSTEMTIME &sysTime);
	void get_SerialNumber(CkString &str);
	bool get_ForTimeStamping(void);
	bool get_ForCodeSigning(void);
	bool get_ForClientAuthentication(void);
	bool get_ForServerAuthentication(void);
	bool get_ForSecureEmail(void);
	void get_Version(CkString &str);

	// Error log retrieval and saving (these methods are common to all Chilkat VC++ classes.)
	bool SaveLastError(const char *filename);
        void LastErrorXml(CkString &str);
        void LastErrorHtml(CkString &str);
        void LastErrorText(CkString &str);


	// END PUBLIC INTERFACE
	
};

#endif
